Package: RColetum
Type: Package
Title: Access your Coletum's Data from API
Version: 1.0.0
Authors@R: c(
    person("André", "Smaniotto", , "smaniotto@geosapiens.com.br", c("aut", "cre")),
    person("Marcelo", "Magnani", , "marcelo@geosapiens.com.br", "aut"),
    person("Rodrigo", "Sant'Ana", , "oc.rodrigosantana@gmail.com", "aut"),
    person("GeoSapiens", role = c("cph", "fnd"))
    )
Maintainer: André Smaniotto <smaniotto@geosapiens.com.br>
Description: Get your data (forms, structures, answers) from Coletum 
    <https://coletum.com> to handle and analyse.
License: LGPL-3
URL: https://github.com/geo-sapiens/RColetum
BugReports: https://github.com/geo-sapiens/RColetum/issues
Encoding: UTF-8
Imports: httr, jsonlite, dplyr, stats
RoxygenNote: 7.3.2
Suggests: testthat
NeedsCompilation: no
Packaged: 2026-04-16 21:53:04 UTC; andresmaniotto
Author: André Smaniotto [aut, cre],
  Marcelo Magnani [aut],
  Rodrigo Sant'Ana [aut],
  GeoSapiens [cph, fnd]
Depends: R (>= 4.1.0)
Repository: CRAN
Date/Publication: 2026-04-16 22:12:04 UTC
Built: R 4.6.0; ; 2026-04-26 14:44:50 UTC; unix
