#' RColetum
#'
#' An R package to get data from \href{https://coletum.com}{Coletum}.
#'
#' @section \pkg{RColetum} functions:
#' The currents functions that are provide by \pkg{RColetum} are:
#' \itemize{
#'
#' \item \code{\link{GetForms}}: get the information about all forms.
#' \item \code{\link{GetForm}}: get the metadata and field structure of a form.
#' \item \code{\link{GetAnswers}}: get the all the answers of a form or
#' personalize with filters and take just what you need.
#' \item \code{\link{FlattenAnswers}}: flatten a \code{GetAnswers} result into
#' a single data frame.
#'
#' }
#'
"_PACKAGE"
