% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetForm.R
\name{GetForm}
\alias{GetForm}
\title{Get form metadata and field structure.}
\usage{
GetForm(token, idForm, nameForm = NULL)
}
\arguments{
\item{token}{A string access token.}

\item{idForm}{Numeric Id of the required form.}

\item{nameForm}{String name of the required form. Used only when
\code{idForm} is not supplied. When this parameter is used, one extra
access quota is spent.}
}
\value{
A list with elements: \code{id}, \code{name}, \code{description},
  \code{status}, \code{category}, \code{version}, \code{public_answers},
  and \code{components} (a nested data frame representing the form's field
  schema, where each row is a component with columns \code{id},
  \code{type}, \code{label}, \code{help_block}, \code{maximum},
  \code{minimum}, \code{visibility}, and — for group components —
  \code{components}).
}
\description{
Retrieves the metadata and complete component (field) structure of a
specific form. This function replaces the former \code{GetFormStructure}.
}
\details{
To get more details about the fields provided by the result, please visit the
\href{https://coletum.com/en_US/webservice/v2/docs}{API documentation}.
}
\examples{
\donttest{
GetForm("cizio7xeohwgc8k4g4koo008kkoocwg", 5705)
GetForm("cizio7xeohwgc8k4g4koo008kkoocwg", nameForm = "RColetum Test - Iris")
GetForm(token = "cizio7xeohwgc8k4g4koo008kkoocwg",
        nameForm = "RColetum Test - Iris")
}
}
